Qt-Widgets
=============

.. toctree::

.. autoclass:: clickqt.widgets.core.QCheckableCombobox.QCheckableComboBox
    :show-inheritance:
    :members: checkItems, addItem, addItems, updateText, getData

.. autoclass:: clickqt.widgets.core.QPathDialog.QPathDialog
    :show-inheritance:
    :members: selectedPath